
# Slot: update date


date on which an entity was updated. This can be applied to nodes or edges

URI: [biolink:update_date](https://w3id.org/biolink/vocab/update_date)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..1</sub> [Date](types/Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

